Flask-WTF
=========

Simple integration of Flask and WTForms, including CSRF, file upload,
and reCAPTCHA.

Links
-----

-   Documentation: https://flask-wtf.readthedocs.io/
-   Changes: https://flask-wtf.readthedocs.io/changes/
-   PyPI Releases: https://pypi.org/project/Flask-WTF/
-   Source Code: https://github.com/wtforms/flask-wtf/
-   Issue Tracker: https://github.com/wtforms/flask-wtf/issues/
-   Chat: https://discord.gg/pallets
